import { Connection } from '../jsonrpc2/connection';
import { IRPCProtocol, ProxyIdentifier } from '../../protocol/proxy-identifier';
/**
 *
 * @param prefix
 * @param connection
 * @param handler
 * @return A proxy that translates method calls on itself to requests sent on the {@link connection}.
 */
export declare function createProxyAndHandleRequests(prefix: string, connection: Connection, handler: any): any;
export declare function createExtensionProxy(connection: Connection, rpcId: number): any;
/**
 * Creates a Proxy that translates method calls (whose name begins with "$") on the returned object to messages
 * named `${prefix}/${name}` on the connectino.
 *
 * @param connection - The connection to send messages on when proxy methods are called.
 * @param prefix - The name prefix for connection methods.
 */
export declare function createProxy(connection: Connection | any, prefix: string): any;
/**
 * Forwards all requests received on the connection to the corresponding method on the handler object. The
 * connection method `${prefix}/${name}` corresponds to `${name}` method on the handler object.
 *
 *
 * @param connection - connection
 * @param prefix  - connection prefix
 * @param handler - An instance of a class whose methods should be called when the connection receives
 *                  corresponding requests, or an object created with Object.create(null) (or otherwise with a null
 *                  prototype) whose properties contain functions to be called.
 */
export declare function handleRequests(connection: Connection, prefix: string, handler: any): void;
/**
 * Forwards all requests received on the connection to the corresponding method on the server side.
 *
 * @param connection - connection
 * @param extContext - Remote Context, usually for connecting to Server side providers
 * @param identifier - Remote Actor Identifier.
 */
export declare function handleServerProxyRequest<T>(connection: Connection, remoteProtocol: IRPCProtocol, identifier: ProxyIdentifier<T>): void;
/**
 * Forwards all requests received on the connection to the corresponding method on the server side.
 *
 * @param connection - connection
 * @param extContext - Remote Context, usually for connecting to Server side providers
 * @param identifier - Remote Actor Identifier.
 */
export declare function handleServerProxyRequests(connection: Connection, remoteProtocol: IRPCProtocol, identifiers: {
    [key: string]: ProxyIdentifier<any>;
}): void;
